==> arna-0.4.4.tar.gz: ROADMAP.md <==
# Arna Framework's roadmap

## 1.0.0

- Finalizing the current set of widgets.

  - Base (20/20)

    - [x] ArnaApp [TODO]
    - [x] ArnaBanner
    - [x] ArnaBaseWidget
    - [x] ArnaBottomBarItem
    - [x] ArnaBottomBar
    - [x] ArnaDrawer
    - [x] ArnaFeedback
    - [x] ArnaHeaderBar
    - [x] ArnaMasterDetailScaffold
    - [x] ArnaMasterItem
    - [x] ArnaPage
    - [x] ArnaProgressIndicator
    - [x] ArnaPageRoute
    - [x] ArnaScaffold
    - [x] ArnaScrollbar
    - [x] ArnaSearchField [TODO]
    - [x] ArnaSideBarItem
    - [x] ArnaSideScaffold
    - [x] ArnaSnackBar
    - [x] ArnaTooltip

  - Buttons (7/7)

    - [x] ArnaBorderlessButton
    - [x] ArnaButton
    - [x] ArnaColorButton
    - [x] ArnaIconButton
    - [x] ArnaLinkedButtons
    - [x] ArnaPopupMenuButton
    - [x] ArnaTextButton

  - Containers (6/6)

    - [x] ArnaBadge
    - [x] ArnaCard
    - [x] ArnaColumn
    - [x] ArnaExpansionPanel
    - [x] ArnaListTile
    - [x] ArnaList

  - Dialogs (0/2)

    - [ ] ArnaAlertDialog
    - [ ] ArnaPopupDialog

  - Dividers (1/1)

    - [x] ArnaDivider

  - Inputs (8/11)

    - [x] ArnaCheckBoxListTile
    - [x] ArnaCheckBox
    - [ ] ArnaPopupMenu
    - [x] ArnaRadioListTile
    - [x] ArnaRadio
    - [x] ArnaSegmentedControl
    - [x] ArnaSliderListTile
    - [ ] ArnaSlider
    - [x] ArnaSwitchListTile
    - [x] ArnaSwitch
    - [ ] ArnaTextField

  - Theme (5/5)
    - [x] ArnaColors
    - [x] ArnaTextTheme
    - [x] ArnaThemeData
    - [x] ArnaTheme
    - [x] ArnaTypography

==> arna-0.4.6.tar.gz: ROADMAP.md <==
# Arna Framework's roadmap

## 1.0.0

- Finalizing the current set of widgets.

  - Base (21/21)

    - [x] ArnaApp [TODO]
    - [x] ArnaBanner
    - [x] ArnaBaseWidget
    - [x] ArnaBottomBarItem
    - [x] ArnaBottomBar
    - [x] ArnaDivider
    - [x] ArnaDrawer
    - [x] ArnaFeedback
    - [x] ArnaHeaderBar
    - [x] ArnaMasterDetailScaffold
    - [x] ArnaMasterItem
    - [x] ArnaPage
    - [x] ArnaProgressIndicator
    - [x] ArnaPageRoute
    - [x] ArnaScaffold
    - [x] ArnaScrollbar
    - [x] ArnaSearchField [TODO]
    - [x] ArnaSideBarItem
    - [x] ArnaSideScaffold
    - [x] ArnaSnackBar [TODO]
    - [x] ArnaTextSelectionControls
    - [x] ArnaTooltip

  - Buttons (6/6)

    - [x] ArnaBorderlessButton
    - [x] ArnaButton
    - [x] ArnaColorButton
    - [x] ArnaIconButton
    - [x] ArnaLinkedButtons
    - [x] ArnaTextButton

  - Containers (5/5)

    - [x] ArnaBadge
    - [x] ArnaCard
    - [x] ArnaExpansionPanel
    - [x] ArnaListTile
    - [x] ArnaList

  - Dialogs (2/2)

    - [x] ArnaDialog
    - [x] ArnaPopupDialog

  - Inputs (12/12)

    - [x] ArnaCheckBoxListTile
    - [x] ArnaCheckBox
    - [x] ArnaPopupMenu
    - [x] ArnaRadioListTile
    - [x] ArnaRadio
    - [x] ArnaSegmentedControl
    - [x] ArnaSliderListTile
    - [x] ArnaSlider
    - [x] ArnaSwitchListTile
    - [x] ArnaSwitch
    - [x] ArnaTextField
    - [x] ArnaTextFormField

  - Theme (5/5)
    - [x] ArnaColors
    - [x] ArnaTextTheme
    - [x] ArnaThemeData
    - [x] ArnaTheme
    - [x] ArnaTypography
